# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
from typing import Any, Awaitable, TYPE_CHECKING

from azure.core import AsyncPipelineClient
from azure.core.rest import AsyncHttpResponse, HttpRequest

from .. import models as _models
from .._serialization import Deserializer, Serializer
from ._configuration import IgnosPortalConfiguration
from .operations import (
    AssetsOperations,
    AzureRegionsOperations,
    CdfOperations,
    CncSetupOperations,
    CountriesOperations,
    CustomerOrdersOperations,
    CustomersOperations,
    ElectricalOperations,
    ExternalAccessOperations,
    ExternalOperations,
    LinksOperations,
    MachineAlarmsOperations,
    MachineUtilizationOperations,
    MeOperations,
    MeasurementFormSchemasOperations,
    MeasurementFormsInstancesOperations,
    MeasuringToolsOperations,
    OperatorCalculatorsOperations,
    PowerOperations,
    PresentationOperations,
    SuppliersOperations,
    SustainabilityOperations,
    SystemHealthDashboardOperations,
    UploadOperations,
    UsersOperations,
    WeldingOperations,
    WorkordersOperations,
    WorkspaceTemplatesAdminOperations,
    WorkspaceTemplatesOperations,
    WorkspacesOperations,
)

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from azure.core.credentials_async import AsyncTokenCredential


class IgnosPortal:  # pylint: disable=client-accepts-api-version-keyword,too-many-instance-attributes
    """IgnosPortal.

    :ivar assets: AssetsOperations operations
    :vartype assets: ignos.api.client.aio.operations.AssetsOperations
    :ivar azure_regions: AzureRegionsOperations operations
    :vartype azure_regions: ignos.api.client.aio.operations.AzureRegionsOperations
    :ivar cdf: CdfOperations operations
    :vartype cdf: ignos.api.client.aio.operations.CdfOperations
    :ivar cnc_setup: CncSetupOperations operations
    :vartype cnc_setup: ignos.api.client.aio.operations.CncSetupOperations
    :ivar countries: CountriesOperations operations
    :vartype countries: ignos.api.client.aio.operations.CountriesOperations
    :ivar customers: CustomersOperations operations
    :vartype customers: ignos.api.client.aio.operations.CustomersOperations
    :ivar customer_orders: CustomerOrdersOperations operations
    :vartype customer_orders: ignos.api.client.aio.operations.CustomerOrdersOperations
    :ivar workorders: WorkordersOperations operations
    :vartype workorders: ignos.api.client.aio.operations.WorkordersOperations
    :ivar external: ExternalOperations operations
    :vartype external: ignos.api.client.aio.operations.ExternalOperations
    :ivar external_access: ExternalAccessOperations operations
    :vartype external_access: ignos.api.client.aio.operations.ExternalAccessOperations
    :ivar electrical: ElectricalOperations operations
    :vartype electrical: ignos.api.client.aio.operations.ElectricalOperations
    :ivar welding: WeldingOperations operations
    :vartype welding: ignos.api.client.aio.operations.WeldingOperations
    :ivar links: LinksOperations operations
    :vartype links: ignos.api.client.aio.operations.LinksOperations
    :ivar machine_alarms: MachineAlarmsOperations operations
    :vartype machine_alarms: ignos.api.client.aio.operations.MachineAlarmsOperations
    :ivar machine_utilization: MachineUtilizationOperations operations
    :vartype machine_utilization: ignos.api.client.aio.operations.MachineUtilizationOperations
    :ivar me: MeOperations operations
    :vartype me: ignos.api.client.aio.operations.MeOperations
    :ivar measurement_form_schemas: MeasurementFormSchemasOperations operations
    :vartype measurement_form_schemas:
     ignos.api.client.aio.operations.MeasurementFormSchemasOperations
    :ivar measurement_forms_instances: MeasurementFormsInstancesOperations operations
    :vartype measurement_forms_instances:
     ignos.api.client.aio.operations.MeasurementFormsInstancesOperations
    :ivar measuring_tools: MeasuringToolsOperations operations
    :vartype measuring_tools: ignos.api.client.aio.operations.MeasuringToolsOperations
    :ivar operator_calculators: OperatorCalculatorsOperations operations
    :vartype operator_calculators: ignos.api.client.aio.operations.OperatorCalculatorsOperations
    :ivar power: PowerOperations operations
    :vartype power: ignos.api.client.aio.operations.PowerOperations
    :ivar presentation: PresentationOperations operations
    :vartype presentation: ignos.api.client.aio.operations.PresentationOperations
    :ivar suppliers: SuppliersOperations operations
    :vartype suppliers: ignos.api.client.aio.operations.SuppliersOperations
    :ivar sustainability: SustainabilityOperations operations
    :vartype sustainability: ignos.api.client.aio.operations.SustainabilityOperations
    :ivar system_health_dashboard: SystemHealthDashboardOperations operations
    :vartype system_health_dashboard:
     ignos.api.client.aio.operations.SystemHealthDashboardOperations
    :ivar upload: UploadOperations operations
    :vartype upload: ignos.api.client.aio.operations.UploadOperations
    :ivar users: UsersOperations operations
    :vartype users: ignos.api.client.aio.operations.UsersOperations
    :ivar workspaces: WorkspacesOperations operations
    :vartype workspaces: ignos.api.client.aio.operations.WorkspacesOperations
    :ivar workspace_templates_admin: WorkspaceTemplatesAdminOperations operations
    :vartype workspace_templates_admin:
     ignos.api.client.aio.operations.WorkspaceTemplatesAdminOperations
    :ivar workspace_templates: WorkspaceTemplatesOperations operations
    :vartype workspace_templates: ignos.api.client.aio.operations.WorkspaceTemplatesOperations
    :param credential: Credential needed for the client to connect to Azure. Required.
    :type credential: ~azure.core.credentials_async.AsyncTokenCredential
    :keyword endpoint: Service URL. Required. Default value is "".
    :paramtype endpoint: str
    """

    def __init__(self, credential: "AsyncTokenCredential", *, endpoint: str = "", **kwargs: Any) -> None:
        self._config = IgnosPortalConfiguration(credential=credential, **kwargs)
        self._client = AsyncPipelineClient(base_url=endpoint, config=self._config, **kwargs)

        client_models = {k: v for k, v in _models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)
        self._serialize.client_side_validation = False
        self.assets = AssetsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.azure_regions = AzureRegionsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.cdf = CdfOperations(self._client, self._config, self._serialize, self._deserialize)
        self.cnc_setup = CncSetupOperations(self._client, self._config, self._serialize, self._deserialize)
        self.countries = CountriesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.customers = CustomersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.customer_orders = CustomerOrdersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.workorders = WorkordersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.external = ExternalOperations(self._client, self._config, self._serialize, self._deserialize)
        self.external_access = ExternalAccessOperations(self._client, self._config, self._serialize, self._deserialize)
        self.electrical = ElectricalOperations(self._client, self._config, self._serialize, self._deserialize)
        self.welding = WeldingOperations(self._client, self._config, self._serialize, self._deserialize)
        self.links = LinksOperations(self._client, self._config, self._serialize, self._deserialize)
        self.machine_alarms = MachineAlarmsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.machine_utilization = MachineUtilizationOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.me = MeOperations(self._client, self._config, self._serialize, self._deserialize)
        self.measurement_form_schemas = MeasurementFormSchemasOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.measurement_forms_instances = MeasurementFormsInstancesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.measuring_tools = MeasuringToolsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.operator_calculators = OperatorCalculatorsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.power = PowerOperations(self._client, self._config, self._serialize, self._deserialize)
        self.presentation = PresentationOperations(self._client, self._config, self._serialize, self._deserialize)
        self.suppliers = SuppliersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.sustainability = SustainabilityOperations(self._client, self._config, self._serialize, self._deserialize)
        self.system_health_dashboard = SystemHealthDashboardOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.upload = UploadOperations(self._client, self._config, self._serialize, self._deserialize)
        self.users = UsersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.workspaces = WorkspacesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.workspace_templates_admin = WorkspaceTemplatesAdminOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.workspace_templates = WorkspaceTemplatesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )

    def send_request(self, request: HttpRequest, **kwargs: Any) -> Awaitable[AsyncHttpResponse]:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = await client.send_request(request)
        <AsyncHttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.AsyncHttpResponse
        """

        request_copy = deepcopy(request)
        request_copy.url = self._client.format_url(request_copy.url)
        return self._client.send_request(request_copy, **kwargs)

    async def close(self) -> None:
        await self._client.close()

    async def __aenter__(self) -> "IgnosPortal":
        await self._client.__aenter__()
        return self

    async def __aexit__(self, *exc_details) -> None:
        await self._client.__aexit__(*exc_details)
